#ifndef CURSORMANAGER_H
#define CURSORMANAGER_H

#include <sdl.h>
#include <map>
#include <string>

/**\brief
 * Classe Cursor
 *
 * Classe uniquement accessible par le CursorManager
 */
class Cursor
{
    ////////////////////////////////
    //  FONCTIONS MEMBRES
    ////////////////////////////////

    /// Constructeur
    Cursor(std::string const & FileName);

    /// Constructeur
    Cursor();

    /// Destructeur
    ~Cursor();

    /// Affiche ce curseur
    void setCursor() const;

    ////////////////////////////////
    //  ATTRIBUTS MEMBRES
    ////////////////////////////////

    /// Pointeur vers le curseur
    SDL_Cursor * CursorPointer;

    ////////////////////////////////
    //  AMIS
    ////////////////////////////////

    friend class CursorManager;
};




/**\brief
 * Classe CursorManager
 *
 * Classe singleton de gestion des curseurs
 */
class CursorManager
{
    ////////////////////////////////
    //  FONCTIONS STATIQUES
    ////////////////////////////////

    public:
        /// Dfinis le Curseur  afficher
        static void setCursor(const std::string & name = "");

    ////////////////////////////////
    //  ATTRIBUTS STATIQUES
    ////////////////////////////////

    private:
        /// Singleton de gestion des curseurs
        static CursorManager * Instance;

    ////////////////////////////////
    //  FONCTIONS MEMBRES
    ////////////////////////////////

    public:
        /// Destructeur
        virtual ~CursorManager();

    private:
        /// Constructeur
        CursorManager();

        /// Le constructeur par copie est dclar priv pour interdire son utilisation...
        CursorManager(const CursorManager &);

        /// L'oprateur d'affectation est dclar priv pour interdire son utilisation...
        CursorManager & operator=(const CursorManager &);


    ////////////////////////////////
    //  ATTRIBUTS MEMBRES
    ////////////////////////////////

    private:
        /// Liste des curseurs
        std::map<std::string, Cursor * > CursorList;

};

#endif // FONTMANAGER_H
